package com.lantone.qc.trans.changx;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.keys.ModelStandardKeys;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.MapUtil;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.Preproc;

import java.util.List;
import java.util.Map;

/**
 * @Description: 入院记录文档生成
 * @author: rengb
 * @time: 2020/3/5 15:47
 */
public class ChangxBeHospitalizedDocTrans extends ModelDocTrans {

    @Override
    public BeHospitalizedDoc extract(MedrecVo medrecVo) {
        String content = ((List<String>) medrecVo.getContent().get("content")).get(0);
        int index1 = content.indexOf("初步诊断") + 5;
        int index2 = content.indexOf("\n", index1) - 1;
        if (index1 < index2) {
            content = content.substring(0, index1)
                    + StringUtil.specialCharComma(content.substring(index1, index2))
                    + content.substring(index2);
        }

        int index3 = content.indexOf("辅助检查");
        content = content.substring(0, index3) + "\n" + content.substring(index3);

        List<String> targetTitles = Lists.newArrayList();
        List<String> sourceTitles = ListUtil.isEmpty(medrecVo.getLabel()) ? ModelStandardKeys.beHospitalized : medrecVo.getLabel();
        sourceTitles.forEach(sourceTitle -> {
            String targetTitle = "";
            for (int index = 0; index < sourceTitle.length(); index++) {
                if (index == sourceTitle.length() - 1) {
                    targetTitle += sourceTitle.substring(index, index + 1);
                } else {
                    targetTitle += sourceTitle.substring(index, index + 1) + "[\\s\\p{Zs}]*";
                }
            }
            targetTitles.add(targetTitle);
        });

        Map<String, String> sourceMap = Preproc.extract_doc_pub(false, targetTitles, content);
        Map<String, String> targetMap = MapUtil.copyMap((Map) sourceMap);
        targetMap.put("体格检查", targetMap.get("体格检查（一）"));
        targetMap.put("专科体格检查", targetMap.get("体格检查（二）"));
        targetMap.remove("体格检查（一）");
        targetMap.remove("体格检查（二）");

        BeHospitalizedDoc beHospitalizedDoc = ModelDocGenerate.beHospitalizedDocGen(targetMap);
        beHospitalizedDoc.setPageData((Map) sourceMap);

        return beHospitalizedDoc;
    }

}